@@ -71,7 +71,6 @@
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
@@ -114,10 +113,11 @@ enum : int {
     SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                = 26,
     SBK_QSQLRELATIONALTABLEMODEL_IDX                         = 25,
     SBK_QSQLRESULT_BINDINGSYNTAX_IDX                         = 28,
+    SBK_QSQLRESULT_VIRTUALHOOKOPERATION_IDX                  = 29,
     SBK_QSQLRESULT_IDX                                       = 27,
-    SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                      = 30,
-    SBK_QSQLTABLEMODEL_IDX                                   = 29,
-    SBK_QtSql_IDX_COUNT                                      = 31
+    SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                      = 31,
+    SBK_QSQLTABLEMODEL_IDX                                   = 30,
+    SBK_QtSql_IDX_COUNT                                      = 32
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtSqlTypes;
@@ -175,6 +175,7 @@ template<> inline PyTypeObject *SbkType< ::QSqlRelationalDelegate >() { return r
 template<> inline PyTypeObject *SbkType< ::QSqlRelationalTableModel::JoinMode >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlRelationalTableModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSqlResult::BindingSyntax >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_BINDINGSYNTAX_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSqlResult::VirtualHookOperation >() { return SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_VIRTUALHOOKOPERATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide6_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
